@@ -240,7 +240,7 @@ class SolveCDF(SolveUnc):
         """
         return super().generator(nt, F0, d0, v0, static_ic)
 
-    def fsolve(self, force, freq, incrb=2):
+    def fsolve(self, force, freq, incrb=2, rf_disp_only=False):
         """
         Solve frequency-domain modal equations of motion using
         uncoupled equations.
@@ -258,4 +258,4 @@ class SolveCDF(SolveUnc):
             :class:`SolveUnc`), :func:`SolveUnc.fsolve` will raise
             a ``NotImplementedError`` exception.
         """
-        return super().fsolve(force, freq, incrb)
+        return super().fsolve(force, freq, incrb, rf_disp_only)
